self.machine
============

.. autoclass:: mpf.core.machine.MachineController
   :members:
   :show-inheritance:

   .. rubric:: Accessing the machine controller in code

   The machine controller is the main component in MPF, accessible via
   ``self.machine``. See the :doc:`/overview/index` for details.

   .. rubric:: Methods & Attributes

   The machine controller has the following methods & attributes available. Note that methods & attributes inherited from
   base classes are not included here.